@@ -22,7 +22,6 @@ FILENAMES_PACKAGE_CONTENT_PATHS = (
     "pyproject_toml",
     "readme",
     "private",
-    "pypitk_config",
     "pypitk_package",
 )
 SUBDIR_STRUCTURE = f"""
@@ -165,3 +164,6 @@ CLI_HELP_PROMPT = """
 CLI_ENTRY_PROMPT = """
 
 """
+
+
+FIELD_DELIMITERS = ("_", "-", ".")
